@@ -3,8 +3,9 @@ package edu.mayo.bior.catalog.verification;
 import com.google.gson.*;
 import edu.mayo.bior.catalog.*;
 import edu.mayo.pipes.history.ColumnMetaData;
-import org.apache.log4j.Logger;
-import org.apache.log4j.lf5.LogLevel;
+
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import java.io.*;
 import java.util.*;
@@ -21,7 +22,7 @@ import java.util.*;
  */
 public class CatalogRowVerifier
 {
-   private static final Logger sLogger = Logger.getLogger(CatalogRowVerifier.class);
+   private static final Logger sLogger = LoggerFactory.getLogger(CatalogRowVerifier.class);
 
    // 5GB. If catalog file bigger than this, stop reading after past chunk
    private static final long FILE_SIZE_THRESHOLD = 5l * 1024 * 1024 * 1024;
@@ -105,7 +106,6 @@ public class CatalogRowVerifier
          StringBuilder msgBuf = new StringBuilder();
          msgBuf.append(String.format("Column '%s'", colName));
 
-         LogLevel entryLogLvl;
          long numTimesInCatalog = mJsonVerifier.getNumberOfTimesKeySeenInCatalog(colName);
          if (numTimesInCatalog == 0)
          {
