@@ -17,8 +17,8 @@ import edu.mayo.genomicutils.refassembly.*;
 import edu.mayo.pipes.JSON.lookup.LookupPipe;
 import edu.mayo.pipes.exceptions.InvalidPipeInputException;
 import edu.mayo.pipes.history.*;
-import edu.mayo.senders.Sender;
-import edu.mayo.senders.SystemOutSender;
+import edu.mayo.mq.sender.Sender;
+import edu.mayo.mq.sender.SystemOutSender;
 import java.io.IOException;
 import java.util.*;
 
@@ -595,7 +595,8 @@ public class Variant2JSONPipe extends AbstractPipe<History, History>
 		// NOTE: Due to a change in the dbSNP catalog, the "POS" field has changed from a String to an Integer
 		//       "POS" was a String in dbSNP version 142, and an Integer in 150
 		//      (use the String.valueOf() method instead of relying on converting from String to String, or Integer to String as in the new case)
-		String  position = String.valueOf(posPath.read(json));
+		Object  posObj = posPath.read(json);
+		String  position = String.valueOf(posObj);
 		String  chrom = getFromColumn (result, chromosomeCol);
 		String  pos = getFromColumn (result, positionCol);
 		
