@@ -17,7 +17,9 @@ import java.util.Set;
 import java.util.TreeSet;
 
 import org.apache.commons.io.FileUtils;
-import org.apache.log4j.Logger;
+
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.google.gson.JsonArray;
 import com.google.gson.JsonElement;
@@ -52,10 +54,10 @@ public class VcfInfoColumnBuilder {
 	//private static final int INFO_COLUMN = 7;
 
 	//public final String DEFAULT_DESCRIPTION = "BioR property file missing description";
-    //public final String DEFAULT_TYPE = "String";
+	//public final String DEFAULT_TYPE = "String";
 	//public final String DEFAULT_NUMBER = ".";
     
-	private static final Logger sLogger = Logger.getLogger(VcfInfoColumnBuilder.class);
+	private static final Logger sLogger = LoggerFactory.getLogger(VcfInfoColumnBuilder.class);
 	
     /** During the queue-filling stage at first, we gather a list of X lines (ex: 1000) to
      *  determine what all of the key-value pairs should be when constructing the ##INFO header lines     */
