@@ -15,14 +15,16 @@ import java.util.zip.GZIPInputStream;
 
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.lang.StringUtils;
-import org.apache.log4j.Logger;
+
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.google.code.externalsorting.ExternalSort;
 import com.jayway.jsonpath.InvalidPathException;
 import com.jayway.jsonpath.JsonPath;
 import com.jayway.jsonpath.Predicate;
 import com.tinkerpop.pipes.Pipe;
-import com.tinkerpop.pipes.transform.IdentityPipe;
+import com.tinkerpop.pipes.IdentityPipe;
 import com.tinkerpop.pipes.util.Pipeline;
 
 import edu.mayo.bior.catalog.HumanBuildAssembly;
@@ -48,7 +50,7 @@ import net.minidev.json.JSONArray;
  */
 public class TjsonToCatalog {
 
-	private static final Logger sLogger = Logger.getLogger(TjsonToCatalog.class);
+	private static final Logger sLogger = LoggerFactory.getLogger(TjsonToCatalog.class);
 
 	protected String[] mUserChromList = new String[0];
 	protected String[] mHumanChromList = new String[0];
