@@ -4,7 +4,8 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * Utility that connects an InputStream to an OutputStream.
@@ -14,7 +15,7 @@ import org.apache.log4j.Logger;
  */
 public class StreamConnector implements Runnable {
 
-	private final Logger sLogger = Logger.getLogger(StreamConnector.class);
+	private final Logger sLogger = LoggerFactory.getLogger(StreamConnector.class);
 
 	private InputStream mInStream;
 	private OutputStream mOutStream;
@@ -49,4 +50,4 @@ public class StreamConnector implements Runnable {
 		}
 	}
 
-}
\ No newline at end of file
+}
