@@ -127,8 +127,7 @@ public class BuildInfoTest
 			   					+ BuildInfoKey.MAKE_JSON_SCRIPT_PATH + "=" + makeJsonScript.getCanonicalPath() + "\n"
 			   					+ BuildInfoKey.MAKE_JSON_ARGS 		+ "=--flag\n"
 			   					+ BuildInfoKey.TARGET_DIR 			+ "=" + tempFolder.newFolder().getCanonicalPath() + "\n"
-			   					+ "SomeUnrecognizedKey=val\n"
-			   					+ "AnotherBadKey=xyz\n";
+			   					+ "SomeUnrecognizedKey=val\n";
 	   FileUtils.write(buildInfoFile, buildInfoContents);
 	   
 	   // Redirect System.err to a pipe
@@ -138,9 +137,7 @@ public class BuildInfoTest
 	   System.setErr(tempSysErr);
 	   BuildInfo buildInfo = new BuildInfo(buildInfoFile.getCanonicalPath());
 	   System.setErr(oldSysErr);
-	   assertEquals("Warning: Unrecognized key in build_info.txt file: SomeUnrecognizedKey\n" 
-			   +    "Warning: Unrecognized key in build_info.txt file: AnotherBadKey\n",
-			   		bOut.toString());
+	   assertEquals("Warning: Unrecognized key in build_info.txt file: SomeUnrecognizedKey\n", bOut.toString());
    }
    
 
