@@ -582,7 +582,8 @@ public class CreateCatalogCommandTest  extends BaseFunctionalTest {
     			+ "Build Assembly not recognized: GRCh39\n"
     			+ "Valid build assemblies:\n"
     			+ "  GRCh37\n"
-    			+ "  GRCh38\n\n\n";
+    			+ "  GRCh38\n"
+			+ "  NA\n\n\n";
     	assertEquals(outputInvalid.stderr, expectedErrorMsg, outputInvalid.stderr);
     	assertEquals(outputInvalid.stderr, "", outputInvalid.stdout);
 
@@ -620,6 +621,26 @@ public class CreateCatalogCommandTest  extends BaseFunctionalTest {
 		//printFilesInParentDir(outputPath);
     }
 
+    
+    @Test
+    // Test large structural deletions
+	// NOTE: We were getting an error prior to the fix for large <DEL>s that said:
+	//       "Error: length of the refAllele does not equal (max-min+1):"
+	//       But this should build ok
+    public void largeDels() throws IOException {
+    	String testDir   = "src/test/resources/createCatalog/";
+    	String catalogIn = new File(testDir, "largeDels.json").getCanonicalPath();
+    	String outputPath = mTempFolder.newFolder().getAbsolutePath() +  "/catalog.sorted.tsv.bgz";
+    	
+    	CommandOutput out = runCmdApp("-i", catalogIn, "-o", outputPath);
+    	
+    	assertEquals(out.stderr, "", out.stderr);
+    	assertEquals(out.stdout, "", out.stdout);
+    	assertTrue(0 == out.exit);
+    	
+    	verifyCatalogsSame(testDir + "largeDels.expected.json.bgz", outputPath);
+    }
+
 	
 
 	// TODO:  To test:
