@@ -11,6 +11,10 @@ import java.util.List;
 
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.lang.StringUtils;
+
+import org.apache.log4j.Level;
+import org.apache.log4j.Logger;
+
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Ignore;
@@ -49,6 +53,8 @@ public class Tab2JSONCommandTest extends BaseFunctionalTest {
 	// NOTE: Make sure to reset the history as the static variable can mess with subsequent tests!!!
     @Before
     public void clearStaticHistoryBefore(){
+	    Logger.getLogger(edu.mayo.sage.UsageLogger.class).setLevel(Level.ERROR);
+	    Logger.getLogger(edu.mayo.sage.UsageLoggerBuilder.class).setLevel(Level.ERROR);
     }
 
     @After
