@@ -7,6 +7,7 @@ import static org.junit.Assert.assertFalse;
 
 import java.io.File;
 import java.io.IOException;
+import java.nio.charset.Charset;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
@@ -18,6 +19,8 @@ import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
 
+import com.google.common.io.Files;
+
 import edu.mayo.bior.catalog.verification.CatalogVerifier;
 import edu.mayo.bior.cli.func.BaseFunctionalTest;
 import edu.mayo.bior.cli.func.CommandOutput;
@@ -620,7 +623,75 @@ public class VerifyCommandTest extends BaseFunctionalTest {
 	}
 
 	//=============================================================================================================
+	@Test
+	public void testStructuralVariants() throws IOException, InterruptedException {
+		File verifyOutFile = new File(mTempDir, "verify_output.txt");
+		File ctgBgz = new File(mTempDir, "structuralVariants.tsv.bgz");
+		createCatalog_structuralVariants(ctgBgz);
+		CommandOutput output = runCmdApp(new VerifyCatalogCommand(), "bior_verify_catalog",
+			new String[] {
+				"-" + VerifyCatalogCommand.OPTION_CATALOG_FILE,  ctgBgz.getAbsolutePath(),
+				"-" + VerifyCatalogCommand.OPTION_OUTPUT_FILE,   verifyOutFile.getAbsolutePath()
+			}
+		);
 
+		String verifyTxtOut = FileUtils.readFileToString(verifyOutFile);
+
+		printOutputsForDebugging(output, verifyTxtOut);
+
+		String stderr = removeAllLinesStartingWithSlf4j(output.stderr);
+
+		// TEMP ------------------------------------------------------->>>>
+		//FileUtils.write(new File("/tmp/stdout.log"),  output.stdout);
+		//FileUtils.write(new File("/tmp/stderr.log"),  output.stderr);
+		//FileUtils.write(new File("/tmp/stderr2.log"), stderr);
+		//FileUtils.write(new File("/tmp/verify.txt"),  verifyTxtOut);
+		// <<<<------------------------------------------------------------
+
+		// NOTE: We have one field INFO.HOMSEQ that is declared as an Integer in columns.tsv
+		//       but is a string array ["G"] in the data
+		//       The mismatched type should be reported as "String", and not "JsonArray"
+		assertEquals("", stderr);
+		assertContains(output.stdout, "Verify #ERROR: 1, #WARNING: 0");
+		assertContains(verifyTxtOut,  "ERROR 406: Data type does not match between json [String] and columns.tsv [Integer] for key: INFO.HOMSEQ");
+		assertContains(verifyTxtOut,  "Verified 9 of total 9 rows of catalog");
+	}
+
+	
+	//=============================================================================================================
+	@Test
+	// Need to differentiate between single values and arrays (it was previously not doing so)
+	public void testArrayVsSingle() throws IOException, InterruptedException {
+		File verifyOutFile = new File(mTempDir, "verify_output.txt");
+		File ctgBgz = new File(mTempDir, "singleVsArray.tsv.bgz");
+		createCatalog_singleVsArray(ctgBgz);
+		CommandOutput output = runCmdApp(new VerifyCatalogCommand(), "bior_verify",
+			new String[] {
+				"-" + VerifyCatalogCommand.OPTION_CATALOG_FILE,  ctgBgz.getAbsolutePath(),
+				"-" + VerifyCatalogCommand.OPTION_OUTPUT_FILE,   verifyOutFile.getAbsolutePath()
+			}
+		);
+
+		String verifyTxtOut = FileUtils.readFileToString(verifyOutFile);
+
+		printOutputsForDebugging(output, verifyTxtOut);
+
+		assertEquals("", output.stderr);
+		assertContains(output.stdout, "Verify #ERROR: 6, #WARNING: 0");
+
+		assertContains(verifyTxtOut, "ERROR 415: Count does not match between json and columns.tsv for key: StrSingle");
+		assertContains(verifyTxtOut, "ERROR 415: Count does not match between json and columns.tsv for key: StrArray");
+		assertContains(verifyTxtOut, "ERROR 415: Count does not match between json and columns.tsv for key: IntSingle");
+		assertContains(verifyTxtOut, "ERROR 415: Count does not match between json and columns.tsv for key: IntArray");
+		assertContains(verifyTxtOut, "ERROR 415: Count does not match between json and columns.tsv for key: FloatSingle");
+		assertContains(verifyTxtOut, "ERROR 415: Count does not match between json and columns.tsv for key: FloatArray");
+		
+		assertContains(verifyTxtOut,    "Verified 1 of total 1 rows of catalog");
+	}
+
+	
+
+	//=============================================================================================================
 
 	private List<String> getMetadataOutput() {
 		return Arrays.asList(
@@ -982,6 +1053,43 @@ public class VerifyCommandTest extends BaseFunctionalTest {
     	super.createCatalog(catalogContents, ctgBgz, /*isCreateTabixIndex=*/true);
   	}
 
+	
+	private void createCatalog_structuralVariants(File ctgBgz) throws IOException, InterruptedException {
+    	List<String> catalogContents = Files.readLines(new File("src/test/resources/vcfToTjson/structuralVariants.tjson"), Charset.defaultCharset()); 
+    	super.createCatalog(catalogContents, ctgBgz, /*isCreateTabixIndex=*/true);
+
+    	// Create columns.tsv
+    	File colsTsv = new File(ctgBgz.getParentFile(), getCtgPrefix(ctgBgz) + ".columns.tsv"); 
+    	String colsContent = FileUtils.readFileToString(new File("src/test/resources/vcfToTjson/structuralVariants.columns.tsv"));
+    	FileUtils.write(colsTsv, colsContent);
+    	
+    	// Create the datasource.properties
+    	File datasourceProps = new File(ctgBgz.getParentFile(), getCtgPrefix(ctgBgz) + ".datasource.properties");
+    	String datasrcContents = FileUtils.readFileToString(new File("src/test/resources/vcfToTjson/structuralVariants.datasource.properties"));
+    	FileUtils.write(datasourceProps, datasrcContents);
+    	    	
+    	createBlacklists(ctgBgz);
+  	}
+
+	private void createCatalog_singleVsArray(File ctgBgz) throws IOException, InterruptedException {
+    	List<String> catalogContents = Files.readLines(new File("src/test/resources/singleVsArray.tjson"), Charset.defaultCharset()); 
+    	super.createCatalog(catalogContents, ctgBgz, /*isCreateTabixIndex=*/true);
+
+    	// Create columns.tsv
+    	File colsTsv = new File(ctgBgz.getParentFile(), getCtgPrefix(ctgBgz) + ".columns.tsv"); 
+    	String colsContent = FileUtils.readFileToString(new File("src/test/resources/singleVsArray.columns.tsv"));
+    	FileUtils.write(colsTsv, colsContent);
+    	
+    	// Create the datasource.properties
+    	File datasourceProps = new File(ctgBgz.getParentFile(), getCtgPrefix(ctgBgz) + ".datasource.properties");
+    	String datasrcContents = FileUtils.readFileToString(new File("src/test/resources/singleVsArray.datasource.properties"));
+    	FileUtils.write(datasourceProps, datasrcContents);
+    	    	
+    	createBlacklists(ctgBgz);
+  	}
+
+	
+	
 	private void convertSingleQuotesToDouble(List<String> lines) {
 		for(int i=0; i < lines.size(); i++) {
 			lines.set(i, lines.get(i).replace("'", "\""));
