@@ -14,12 +14,18 @@ import java.io.PrintWriter;
 import java.io.StringReader;
 import java.io.StringWriter;
 import java.io.UnsupportedEncodingException;
+import java.lang.reflect.Field;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
+import org.apache.log4j.Level;
+
+import org.apache.log4j.Logger;
+
 import org.junit.After;
 import org.junit.Before;
 import org.junit.BeforeClass;
@@ -60,12 +66,53 @@ public abstract class BaseFunctionalTest {
 
 	// NOTE: This static block will be called BEFORE any class that extends this class
 	//       (Even before the RemoteFunctionalTest class that extends this one
+	// isBiorToolkitCmdsReq - sets the BIOR_LITE_HOME system variable and adds it to the PATH
 	public static void setBiorToolkitCmdsRequired(boolean isBiorToolkitCmdsReq) throws FileNotFoundException {
+		disableLogging();
 		isBiorToolkitCmdsRequired = isBiorToolkitCmdsReq;
-		setup();
+		try {
+			setup();
+		} catch(Exception e) {
+			e.printStackTrace();
+		}
 	}
 	
 	
+	// Disable the logging so it doesn't pollute the test logs and stdout output
+	private static void disableLogging() {
+	    // For the code below to work, it must be executed before the logger is created!!!
+	    //System.setProperty(org.slf4j.impl.Log4jMSimpleLogger.DEFAULT_LOG_LEVEL_KEY, "TRACE");
+	    //​org.slf4j.Logger log = LoggerFactory.getLogger(App.class);		
+
+	    //Logger root = (Logger) LoggerFactory.getLogger(Logger.ROOT_LOGGER_NAME);
+	    //root.setLevel(Level.INFO);
+	    //Logger.getRootLogger().setLevel(Level.FATAL);
+	    
+		// Prevent Sage info msgs from appearing in the test case outputs
+		// Ex:  "INFO edu.mayo.sage.UsageLoggerBuilder - Getting usage logger using server:bsu-sage.mayo.edu port:33124 failOnError:true protocol:UDP"
+	    Logger.getLogger(edu.mayo.sage.UsageLogger.class).setLevel(Level.ERROR);
+	    Logger.getLogger(edu.mayo.sage.UsageLoggerBuilder.class).setLevel(Level.ERROR);
+	}
+
+
+	public String removeAllLinesStartingWithSlf4j(String stderr) {
+		return stderr.replaceAll("SLF4J: .*\n", "");
+	}
+
+
+	/** Given a multi-line output, remove all headers beginning with "#" */
+	public String removeHeaders(String stdout) {
+		StringBuilder s = new StringBuilder();
+		for(String line : stdout.split("\n")) {
+			if( s.length() > 0 )
+				s.append("\n");
+			if( ! line.startsWith("#"))
+				s.append(line);
+		}
+		return s.toString();
+	}
+
+	
 	// stores the $BIOR_LITE_HOME value
 	protected static String sHomePath;
 
@@ -81,7 +128,7 @@ public abstract class BaseFunctionalTest {
 	}
 
 	
-	public static void setup() throws FileNotFoundException {
+	public static void setup() throws Exception {
 		System.out.println("\n\n=============== BaseFunctionalTest.setup() ====================\n\n");
 		
 		// pass along current environment
@@ -103,6 +150,8 @@ public abstract class BaseFunctionalTest {
 			path  =  sHomePath + "/bin" + SEPARATOR
 				  + path;
 			sEnvVars.put("PATH", path);
+			
+			setEnv(sEnvVars);
 		} else {
 			System.out.println("\n---------- BioR toolkit commands are NOT required ---------------\n");
 		}
@@ -112,6 +161,35 @@ public abstract class BaseFunctionalTest {
 		System.out.println("sEnvVars = " + sEnvVars);
 	}
 
+	
+	// From: https://stackoverflow.com/questions/318239/how-do-i-set-environment-variables-from-java
+	protected static void setEnv(Map<String, String> newenv) throws Exception {
+		try {
+			Class<?> processEnvironmentClass = Class.forName("java.lang.ProcessEnvironment");
+		    Field theEnvironmentField = processEnvironmentClass.getDeclaredField("theEnvironment");
+		    theEnvironmentField.setAccessible(true);
+		    Map<String, String> env = (Map<String, String>) theEnvironmentField.get(null);
+		    env.putAll(newenv);
+		    Field theCaseInsensitiveEnvironmentField = processEnvironmentClass.getDeclaredField("theCaseInsensitiveEnvironment");
+		    theCaseInsensitiveEnvironmentField.setAccessible(true);
+		    Map<String, String> cienv = (Map<String, String>)     theCaseInsensitiveEnvironmentField.get(null);
+		    cienv.putAll(newenv);
+		} catch (NoSuchFieldException e) {
+		    Class[] classes = Collections.class.getDeclaredClasses();
+		    Map<String, String> env = System.getenv();
+		    for(Class cl : classes) {
+		    	if("java.util.Collections$UnmodifiableMap".equals(cl.getName())) {
+		    		Field field = cl.getDeclaredField("m");
+		    		field.setAccessible(true);
+		    		Object obj = field.get(env);
+		    		Map<String, String> map = (Map<String, String>) obj;
+		    		map.clear();
+		    		map.putAll(newenv);
+		    	}
+		    }
+		}
+	}
+	
 	@Before
 	@After
 	public void clearHistory() {
@@ -212,7 +290,7 @@ public abstract class BaseFunctionalTest {
 		if( cmdOut.stderr.contains("/bin/sh: " + scriptName + ": command not found") ) {
 			System.err.println("\nError: Could not find BioR command.  You may need to create a @BeforeClass method\n"
 					+  "in your integration test and call this method to add the BioR commands to the path:\n"
-					+  "  BiorFunctionalTest.setBiorToolkitCmdsRequired(true)\n");
+					+  "  BaseFunctionalTest.setBiorToolkitCmdsRequired(true)\n");
 		}
 		
 		return cmdOut;
