@@ -10,6 +10,8 @@ package edu.mayo.bior.pipeline;
 import java.io.*;
 import java.util.*;
 
+import java.sql.SQLException;
+
 import org.apache.commons.io.FileUtils;
 import org.junit.*;
 
@@ -263,7 +265,7 @@ public class Variant2JSONPipeTestITCase
 	 * @throws IOException	For any file problems
 	 */
 	@Test
-	public void testJSONGenerationBimFile () throws IOException
+	public void testJSONGenerationBimFile () throws IOException, SQLException
 	{
 		String						bimFile = "src/test/resources/testData/VariantToJson/bb.test.bim";
 		String						bimResultsFile = "src/test/resources/testData/VariantToJson/bimResults.txt";
@@ -291,7 +293,7 @@ public class Variant2JSONPipeTestITCase
 	 * @throws IOException	For any file problems
 	 */
 	@Test
-	public void testBimFileAnnotation () throws IOException
+	public void testBimFileAnnotation () throws IOException, SQLException
 	{
 		String					bimFile = "src/test/resources/testData/VariantToJson/bb.test.bim";
 		String					bimResultsFile = "src/test/resources/testData/VariantToJson/bimAnnotatedResults.txt";
@@ -348,7 +350,7 @@ public class Variant2JSONPipeTestITCase
 	 * @throws IOException	For any file problems
 	 */
 	@Test
-	public void testBimFileAnnotations () throws IOException
+	public void testBimFileAnnotations () throws IOException, SQLException
 	{
 		String					bimFile = "src/test/resources/testData/VariantToJson/bb.test.bim";
 		String					bimResultsFile = "src/test/resources/testData/VariantToJson/bimOldDrilledResults.txt";
@@ -598,7 +600,7 @@ public class Variant2JSONPipeTestITCase
 	 * @return	{@linkplain History} to {@linkplain History} {@linkplain Pipeline}, possibly empty, never null
 	 * @throws IOException 
 	 */
-	private Pipeline<History, History> makeFindPipes (List<String> paths, Pipe<History, History> start) throws IOException
+	private Pipeline<History, History> makeFindPipes (List<String> paths, Pipe<History, History> start) throws IOException, SQLException
 	{
 		return makeFindPipes (paths, start, false);
 	}
@@ -613,7 +615,7 @@ public class Variant2JSONPipeTestITCase
 	 * @return	{@linkplain History} to {@linkplain History} {@linkplain Pipeline}, possibly empty, never null
 	 * @throws IOException 
 	 */
-	private Pipeline<History, History> makeFindPipes (List<String> paths, Pipe<History, History> start, boolean reverseList) throws IOException
+	private Pipeline<History, History> makeFindPipes (List<String> paths, Pipe<History, History> start, boolean reverseList) throws IOException, SQLException
 	{
 		Pipeline<History, History>	annotate = new Pipeline<History, History> ();
 		
@@ -754,8 +756,9 @@ public class Variant2JSONPipeTestITCase
 	 * @param start		Where to start looking in the Chromosome
 	 * @param end		Where to stop looking in the Chromosome
 	 * @throws NumberFormatException
+	 * @throws IOException 
 	 */
-	private void testChromosome (RefBasePairLookup genome, String chrom, int start, int end) throws NumberFormatException
+	private void testChromosome (RefBasePairLookup genome, String chrom, int start, int end) throws NumberFormatException, IOException
 	{
 		boolean	isDot = false;
 		boolean	isN = false;
@@ -843,7 +846,7 @@ public class Variant2JSONPipeTestITCase
 	 * @param meta	Name of the test being run
 	 * @return	A String in, String out {@linkplain Pipeline}
 	 */
-	private Pipeline<String, String> getVariant2JsonPipeline (String meta)
+	private Pipeline<String, String> getVariant2JsonPipeline (String meta) throws IOException, SQLException
 	{
 		String						lookupFile = kLookupFile;
 		String						lookupIndexFile = kLookupIndexFile;
