@@ -8,6 +8,8 @@ import java.io.StringWriter;
 
 import org.apache.log4j.PatternLayout;
 import org.apache.log4j.WriterAppender;
+import org.apache.log4j.Logger;
+
 import org.junit.Before;
 import org.junit.BeforeClass;
 import org.junit.Test;
@@ -17,6 +19,8 @@ import edu.mayo.bior.cli.func.BaseFunctionalTest;
 public class TjsonToCatalogNoJsonParsingPipeTest extends BaseFunctionalTest {
 
 	private StringWriter logStringWriter;
+
+	private static Logger logger = Logger.getLogger(TjsonToCatalogNoJsonParsingPipe.class);
 	
 	@BeforeClass
 	public static void beforeAll() {
@@ -27,7 +31,7 @@ public class TjsonToCatalogNoJsonParsingPipeTest extends BaseFunctionalTest {
 		// Capture the log outputs
 		logStringWriter = new StringWriter();
 		WriterAppender appender = new WriterAppender(new PatternLayout(), logStringWriter);
-		TjsonToCatalogNoJsonParsingPipe.sLogger.addAppender(appender);
+		logger.addAppender(appender);
 	}
 	
 	public String getLog() {
@@ -35,6 +39,60 @@ public class TjsonToCatalogNoJsonParsingPipeTest extends BaseFunctionalTest {
 		return logStringWriter.toString();
 	}
 	
+	
+	@Test
+	public void testGetJsonValue() {
+		TjsonToCatalogNoJsonParsingPipe t = new TjsonToCatalogNoJsonParsingPipe(1, true, false);
+		// K as an int - last key-val in json - single value, within json, single value within array, multi-value within array
+		assertEquals("1", 		t.getJsonVal(swapQt("{'_altAlleles':['A','ABC'],'K':1}"), 			"K"));
+		assertEquals("1", 		t.getJsonVal(swapQt("{'_altAlleles':['A','ABC'],'Sub':{'K':1}}"),	"K"));
+		assertEquals("[1]", 	t.getJsonVal(swapQt("{'_altAlleles':['A','ABC'],'K':[1]}"),			"K"));
+		assertEquals("[1,2,3]", t.getJsonVal(swapQt("{'_altAlleles':['A','ABC'],'K':[1,2,3]}"),		"K"));
+
+		// K as a string - last key-val in json - single value, within json, single value within array, multi-value within array
+		assertEquals("1", 						t.getJsonVal(swapQt("{'_altAlleles':['A','ABC'],'K':'1'}"), 			"K"));
+		assertEquals("1", 						t.getJsonVal(swapQt("{'_altAlleles':['A','ABC'],'Sub':{'K':'1'}}"),		"K"));
+		assertEquals(swapQt("['1']"), 			t.getJsonVal(swapQt("{'_altAlleles':['A','ABC'],'K':['1']}"),			"K"));
+		assertEquals(swapQt("['1','2','3']"),	t.getJsonVal(swapQt("{'_altAlleles':['A','ABC'],'K':['1','2','3']}"),	"K"));
+
+		//------
+		// K as an int - first key-val in json - single value, within json, single value within array, multi-value within array
+		assertEquals("1", 		t.getJsonVal(swapQt("{'K':1,'J':2}"), 			"K"));
+		assertEquals("1",		t.getJsonVal(swapQt("{'Sub':{'K':1},'J':2}"),	"K"));
+		assertEquals("[1]", 	t.getJsonVal(swapQt("{'K':[1],'J':2}"),			"K"));
+		assertEquals("[1,2,3]", t.getJsonVal(swapQt("{'K':[1,2,3],'J':2}"),		"K"));
+
+		// K as a string - first key-val in json - single value, within json, single value within array, multi-value within array
+		assertEquals("1", 						t.getJsonVal(swapQt("{'K':'1','_altAlleles':['A','ABC']}"), 			"K"));
+		assertEquals("1", 						t.getJsonVal(swapQt("{'Sub':{'K':'1'},'_altAlleles':['A','ABC']}"),		"K"));
+		assertEquals(swapQt("['1']"), 			t.getJsonVal(swapQt("{'K':['1'],'_altAlleles':['A','ABC']}"),			"K"));
+		assertEquals(swapQt("['1','2','3']"), 	t.getJsonVal(swapQt("{'K':['1','2','3'],'_altAlleles':['A','ABC']}"),	"K"));
+
+		//------
+		// K as an int - mid key-val in json - single value, within json, single value within array, multi-value within array
+		assertEquals("1", 		t.getJsonVal(swapQt("{'A':0,'K':1,'J':2}"), 		"K"));
+		assertEquals("1", 		t.getJsonVal(swapQt("{'A':0,'Sub':{'K':1},'J':2}"),	"K"));
+		assertEquals("[1]", 	t.getJsonVal(swapQt("{'A':0,'K':[1],'J':2}"),		"K"));
+		assertEquals("[1,2,3]", t.getJsonVal(swapQt("{'A':0,'K':[1,2,3],'J':2}"),	"K"));
+
+		// K as a string - mid key-val in json - single value, within json, single value within array, multi-value within array
+		assertEquals("1", 						t.getJsonVal(swapQt("{'A':0,'K':'1','_altAlleles':['A','ABC']}"), 			"K"));
+		assertEquals("1", 						t.getJsonVal(swapQt("{'A':0,'Sub':{'K':'1'},'_altAlleles':['A','ABC']}"),	"K"));
+		assertEquals(swapQt("['1']"), 			t.getJsonVal(swapQt("{'A':0,'K':['1'],'_altAlleles':['A','ABC']}"),			"K"));
+		assertEquals(swapQt("['1','2','3']"), 	t.getJsonVal(swapQt("{'A':0,'K':['1','2','3'],'_altAlleles':['A','ABC']}"),	"K"));
+
+		
+		assertEquals(swapQt("['A','ABC']"), t.getJsonVal(swapQt("{'_altAlleles':['A','ABC']}"), "_altAlleles"));
+		
+		// TODO: This will certainly mess it up for now, but finding the JSON object embedded within the JSON
+		//assertEquals(swapQt("{'A':'123abc'}"), t.getJsonVal(swapQt("{'B':{'A':'123abc'}}"), 	"B"));
+		
+	}
+	
+	private String swapQt(String s) {
+		return s.replace("'", "\"");
+	}
+	
 	@Test
 	public void testReplaceValueInJson() {
 		TjsonToCatalogNoJsonParsingPipe pipe = new TjsonToCatalogNoJsonParsingPipe(1, /*isJsonOnly=*/false, /*isModChr=*/true);
